Structs
- Config
- Configuration for processing. Two things can be set: encoding of input and type of line ending.
Enums
- Encoding
- Enumeration of core-supported encodings.
- Parse
Error - Error which can occur during processing.
- Transform
Mode - Enumeration of possible transforms.
Traits
- Encoding
Checker - Trait used for encoding checking. It should behave like a state machine to which bytes are fed. If the passed bytes causes the checker to enter an invalid state, the method should return false as the indication.
- Transform
- Trait used for transformation of the input. It works on buffers due to the memory consumption and performance reasons.
Functions
- process
- The entry point of loe. It processes the given input and write the result into the given output. Its behavior is dependent on given config.